import 'package:flutter/material.dart';
import 'package:vone_ipfs/bean/upload_result_entity.dart';
import 'package:vone_ipfs/pages/image_picker_dialog.dart';
import 'package:vone_ipfs/pages/online_file_page.dart';
import 'package:vone_ipfs/utils/ifps_dialog_utils.dart';
import 'package:vone_ipfs/utils/ipfs_utils.dart';
import 'package:vone_ipfs/component/vone_image.dart';

import 'defult_upload_view.dart';
///
/// 单图片上传
///
class SingleImageView extends StatefulWidget {
  ///图片的宽度
  final double imageWidth;

  ///图片高度
  final double imageHeight;

  ///图片形状
  final ImageShape shape;

  ///添加图片的按钮
  final Widget? addImageWidget;
  final UploadResultEntity? imageEntity;
  ValueChanged<UploadResultEntity>? singleCallback;

  SingleImageView(
      {Key? key,
      this.imageWidth = 110,
      this.imageHeight = 110,
      this.shape = ImageShape.None,
      this.addImageWidget,
      this.singleCallback,
      this.imageEntity})
      : super(key: key);

  @override
  SingleImageViewState createState() => new SingleImageViewState();
}

class SingleImageViewState extends State<SingleImageView> {
  UploadResultEntity? _image ;

  @override
  Widget build(BuildContext context) {
    return InkWell(
      child: Container(
        width: widget.imageWidth,
        height: widget.imageHeight,
        child: _image==null
            ? (widget.addImageWidget ??
                DefaultUploadView(
                  width: widget.imageWidth,
                  height: widget.imageHeight,
                ))
            : VoneImage(
                imageWidth: double.infinity,
                imageHeight: double.infinity,
                imageUrl: _image!.coverPath.isEmpty?_image!.filePath:_image!.coverPath,
                shape: widget.shape,
                boxFit: BoxFit.fill,
              ),
      ),
      onTap: () {
        _showPickerDialog();
      },
    );
  }

  @override
  void initState() {
    super.initState();
    if(widget.imageEntity!=null){
      _image = widget.imageEntity;
    }

  }

  @override
  void dispose() {
    super.dispose();
  }

  _showPickerDialog() {
    showModalBottomSheet(
        backgroundColor: Colors.transparent,
        context: context, //state.context,
        builder: (BuildContext context) {
          return ImagePickerDialog(
            localCallback: () {
              IPFSDialog.showImageUpload(context, widget.imageWidth,
                  widget.imageHeight, UploadMode.SINGLE, (value) {
                      setState(() {
                        _image = value[0];
                      });
                  });
            },
            cloudCallback: () async {
              Navigator.push(context,
                  MaterialPageRoute(builder: (context) {
                return OnlineFilePage(
                  (result) {
                    setState(() {
                      if (result.isNotEmpty) {
                        _image = UploadResultEntity(IPFSUtils.instance!.getFilePath(result[0].fileID,
                            result[0].fileMeta.fileName),"",result[0].fileMeta.fileName);
                      }
                    });
                  },
                  maxCount: 1,
                );
              }));
            },
          );
        });
  }
}
